@@ -1,12 +1,12 @@
 "UPbrewer" <- function(pik, eps = 1e-06)
 {
-if(any(is.na(pik))) warning("there are missing values in the pik vector")
+if(any(is.na(pik))) stop("there are missing values in the pik vector")
 n=sum(pik)
 if(n!=trunc(n)) stop("the pik's sum is not integer")
 list = pik > eps & pik < 1 - eps
 pikb = pik[list]
 N = length(pikb)
-s=rep(0,length(pik))
+s=pik
 if(N<1) stop("the pik vector has all elements outside of the range [eps,1-eps]")
 else 
 {
